@@ -1,13 +1,11 @@
 /*
-   +----------------------------------------------------------------------+
-   | PHP Version 7                                                        |
    +----------------------------------------------------------------------+
    | Copyright (c) The PHP Group                                          |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
    | available through the world-wide-web at the following url:           |
-   | http://www.php.net/license/3_01.txt                                  |
+   | https://www.php.net/license/3_01.txt                                 |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
@@ -16,7 +14,7 @@
    +----------------------------------------------------------------------+
 */
 
-#define CONFIGURE_COMMAND " './configure'  'ax_cv_have_func_attribute_ifunc=no' '--program-suffix=74' '--with-config-file-path=/usr/pkg/etc/php/7.4' '--with-config-file-scan-dir=/usr/pkg/etc/php/7.4/php.d' '--with-pear=/usr/pkg/lib/php/7.4' '--sysconfdir=/usr/pkg/etc/php/7.4' '--localstatedir=/var' '--without-mysqli' '--without-iconv' '--without-pear' '--without-sqlite3' '--with-external-pcre' '--disable-intl' '--disable-posix' '--disable-opcache' '--disable-pdo' '--disable-json' '--enable-cgi' '--enable-mysqlnd' '--enable-xml' '--enable-ipv6' '--with-openssl=/usr' '--with-readline=/usr/pkg' '--prefix=/usr/pkg' '--build=armv7--netbsdelf-eabihf' '--host=armv7--netbsdelf-eabihf' '--mandir=/usr/pkg/man' '--enable-option-checking=yes' 'build_alias=armv7--netbsdelf-eabihf' 'host_alias=armv7--netbsdelf-eabihf' 'PKG_CONFIG=@TOOLS_PATH.pkg-config@' 'PKG_CONFIG_PATH=' 'PKG_CONFIG_LIBDIR=@PHP_PKGCONFIG_PATH@' 'LIBS='"
+#define CONFIGURE_COMMAND " './configure'  'ax_cv_have_func_attribute_ifunc=no' '--program-suffix=81' '--with-config-file-path=/usr/pkg/etc/php/8.1' '--with-config-file-scan-dir=/usr/pkg/etc/php/8.1/php.d' '--with-pear=/usr/pkg/lib/php/8.1' '--sysconfdir=/usr/pkg/etc/php/8.1' '--localstatedir=/var' '--without-mysqli' '--without-iconv' '--without-pear' '--without-sqlite3' '--with-external-pcre' '--disable-intl' '--disable-posix' '--disable-opcache' '--disable-pdo' '--enable-cgi' '--enable-mysqlnd' '--enable-xml' '--enable-ipv6' '--with-openssl=/usr' '--with-readline=/usr/pkg' '--prefix=/usr/pkg' '--build=powerpc--netbsd' '--host=powerpc--netbsd' '--mandir=/usr/pkg/man' '--enable-option-checking=yes' 'build_alias=powerpc--netbsd' 'host_alias=powerpc--netbsd' 'PKG_CONFIG=/usr/pkg/bin/pkg-config' 'PKG_CONFIG_PATH=' 'PKG_CONFIG_LIBDIR=/usr/pkg/lib/pkgconfig:/usr/pkg/share/pkgconfig:/usr/lib/pkgconfig:/usr/X11R7/lib/pkgconfig' 'LIBS='"
 #define PHP_ODBC_CFLAGS	""
 #define PHP_ODBC_LFLAGS		""
 #define PHP_ODBC_LIBS		""
@@ -26,16 +24,16 @@
 #define PHP_PROG_SENDMAIL	"/usr/sbin/sendmail"
 #define PEAR_INSTALLDIR         ""
 #define PHP_INCLUDE_PATH	".:"
-#define PHP_EXTENSION_DIR       "/usr/pkg/lib/php/7.4/armv7"
+#define PHP_EXTENSION_DIR       "/usr/pkg/lib/php/8.1/powerpc"
 #define PHP_PREFIX              "/usr/pkg"
 #define PHP_BINDIR              "/usr/pkg/bin"
 #define PHP_SBINDIR             "/usr/pkg/sbin"
 #define PHP_MANDIR              "/usr/pkg/man"
 #define PHP_LIBDIR              "/usr/pkg/lib/php/"
 #define PHP_DATADIR             "/usr/pkg/share/php/"
-#define PHP_SYSCONFDIR          "/usr/pkg/etc/php/7.4"
+#define PHP_SYSCONFDIR          "/usr/pkg/etc/php/8.1"
 #define PHP_LOCALSTATEDIR       "/var"
-#define PHP_CONFIG_FILE_PATH    "/usr/pkg/etc/php/7.4"
-#define PHP_CONFIG_FILE_SCAN_DIR    "/usr/pkg/etc/php/7.4/php.d"
+#define PHP_CONFIG_FILE_PATH    "/usr/pkg/etc/php/8.1"
+#define PHP_CONFIG_FILE_SCAN_DIR    "/usr/pkg/etc/php/8.1/php.d"
 #define PHP_SHLIB_SUFFIX        "so"
 #define PHP_SHLIB_EXT_PREFIX    ""
